@@ -2,8 +2,8 @@
 #
 # Project    : ipv6calc
 # File       : test_scenarios.sh
-# Version    : $Id: test_scenarios.sh,v 1.37 2013/10/31 21:24:46 ds6peter Exp $
-# Copyright  : 2001-2013 by Peter Bieringer <pb (at) bieringer.de>
+# Version    : $Id: test_scenarios.sh,v 1.40 2014/04/26 16:16:31 ds6peter Exp $
+# Copyright  : 2001-2014 by Peter Bieringer <pb (at) bieringer.de>
 #
 # Test patterns for ipv6calc (functions only)
 
@@ -127,7 +127,7 @@ testscenarios_ipv6_reserved() {
 	cat <<END | grep -v '^#'
 ::			RFC4291#2.5.2
 ::1			RFC4291#2.5.3
-::0.0.0.2		RFC4291#2.5.5.1
+::0.0.0.2		RFC4291#2.5.5.1			skip-anon-test
 ::255.255.255.255	RFC4291#2.5.5.1
 ::ffff:0.0.0.0		RFC4291#2.5.5.2
 ::ffff:255.255.255.255	RFC4291#2.5.5.2
@@ -216,10 +216,12 @@ a909:16fa:9092:23ff:a909:4941::7		anonymized-prefix
 END
 }
 
-# Test scenarios for genprivacyiid
+# Test scenarios for gienprivacyiid
 testscenarios_genprivacyiid() {
-	#TODO
-	true
+	cat <<END | grep -v '^#'
+0123:4567:89ab:cdef	0123456789abcdef	4462:bdea:8654:776d	486072ff7074945e
+4462:bdea:8654:776d	486072ff7074945e	69ad:92b8:b11d:be18	d74e03fb77f2f561
+END
 }
 
 # Test scenarios for anonymization options (ipv6calc & ipv6loganon)
@@ -409,3 +411,33 @@ testscenarios_showinfo_anonymized_info() {
 1.2.3.4;--db-geoip-disable --db-ip2location-disable;key-no-word;IPV6CALC_FEATURES=ANON_KEEP-TYPE-ASN-CC
 END
 }
+
+testscenarios_kp() {
+	testscenarios_anonymization_options_kp | while IFS="=" read input result; do
+		echo "$input" | awk '{ print $NF }'
+	done | sort | uniq
+
+	testscenarios_anonymization_options | while IFS="=" read input result; do
+		echo "$input" | awk '{ print $NF }'
+	done | sort | uniq
+
+	test_list | while read input filter; do
+		echo "$input"
+	done | sort | uniq
+
+	testscenarios_filter | while read input filter; do
+		echo "$input"
+	done | sort | uniq
+
+	testscenarios_ipv4_reserved | grep -vw "skip-anon-test" | while read input filter rest; do
+		echo "$input"
+	done | sort | uniq
+
+	testscenarios_ipv6_reserved | grep -vw "skip-anon-test" | while read input filter rest; do
+		echo "$input"
+	done | sort | uniq
+
+	testscenarios_auto_good | while read input filter rest; do
+		echo "$input"
+	done | sort | uniq
+}
