@@ -1,8 +1,8 @@
 /*
  * Project    : ipv6calc
  * File       : ipv6loganon.c
- * Version    : $Id: ipv6loganon.c,v 1.27 2013/10/30 20:04:25 ds6peter Exp $
- * Copyright  : 2007-2013 by Peter Bieringer <pb (at) bieringer.de>
+ * Version    : $Id: ipv6loganon.c,v 1.31 2014/05/11 09:49:38 ds6peter Exp $
+ * Copyright  : 2007-2014 by Peter Bieringer <pb (at) bieringer.de>
  * 
  * Information:
  *  Dedicated program for logfile anonymization
@@ -43,7 +43,7 @@
 
 #define LINEBUFFER	16384
 
-long int ipv6calc_debug = 0;
+long int ipv6calc_debug = 0; // ipv6calc_debug usage ok
 int flag_nocache = 0;
 
 /* anonymization default values */
@@ -60,7 +60,7 @@ int feature_kp      = 0; // will be checked later
 
 
 /* prototypes */
-static int anonymizetoken(char *result, const char *token);
+static int anonymizetoken(char *result, const size_t resultstring_length, const char *token);
 static void lineparser();
 
 
@@ -90,7 +90,6 @@ void printversion_verbose(const int level) {
 
 /**************************************************/
 /* main */
-#define DEBUG_function_name "ipv6loganon/main"
 int main(int argc,char *argv[]) {
 	int i, lop, result;
 	uint32_t command = 0;
@@ -103,7 +102,7 @@ int main(int argc,char *argv[]) {
 	ipv6calc_quiet = 1; //default for ipv6loganon
 
 	/* initialize debug value from environment for bootstrap debugging */
-	ipv6calc_debug_from_env();
+	ipv6calc_debug_from_env(); // ipv6calc_debug usage ok
 
 	/* add options */
 	ipv6calc_options_add_common_anon(shortopts, sizeof(shortopts), longopts, &longopts_maxentries);
@@ -119,9 +118,7 @@ int main(int argc,char *argv[]) {
 
 	/* Fetch the command-line arguments. */
 	while ((i = getopt_long(argc, argv, shortopts, longopts, &lop)) != EOF) {
-		if (ipv6calc_debug != 0) {
-			fprintf(stderr, "%s/%s: Parsing option: 0x%08x\n", __FILE__, __func__, i);
-		};
+		DEBUGPRINT_WA(DEBUG_ipv6loganon_general, "Parsing option: 0x%08x", i);
 
 		/* catch common options */
 		result = ipv6calcoptions_common_basic(i, optarg, longopts);
@@ -169,7 +166,7 @@ int main(int argc,char *argv[]) {
 			case 'w':
 			case 'a':
 				if (strlen(optarg) < sizeof(file_out)) {
-					snprintf(file_out, sizeof(file_out) - 1, "%s", optarg);
+					snprintf(file_out, sizeof(file_out), "%s", optarg);
 					file_out_flag = 1;
 				} else {
 					fprintf(stderr, " Output file too long: %s\n", optarg);
@@ -178,10 +175,10 @@ int main(int argc,char *argv[]) {
 
 				switch (i) {
 					case 'w':
-						snprintf(file_out_mode, sizeof(file_out_mode) - 1, "%s", "w");
+						snprintf(file_out_mode, sizeof(file_out_mode), "%s", "w");
 						break;
 					case 'a':
-						snprintf(file_out_mode, sizeof(file_out_mode) - 1, "%s", "a");
+						snprintf(file_out_mode, sizeof(file_out_mode), "%s", "a");
 						break;	
 				};
 				break;
@@ -247,22 +244,14 @@ int main(int argc,char *argv[]) {
 	};
 
 	if (file_out_flag == 1) {
-		if (ipv6calc_debug > 0) {
-			fprintf(stderr, "Output file specified: %s\n", file_out);
-		};
+		DEBUGPRINT_WA(DEBUG_ipv6loganon_general, "Output file specified: %s", file_out);
 
 		FILE_OUT = fopen(file_out, file_out_mode);
 		if (! FILE_OUT) {
 			fprintf(stderr, "Can't open Output file: %s\n", file_out);
 			exit(EXIT_FAILURE);
 		} else {
-			if (ipv6calc_debug > 0) {
-				if (strcmp(file_out_mode, "a") == 0) {
-					fprintf(stderr, "Output file opened successfully in append mode: %s\n", file_out);
-				} else {
-					fprintf(stderr, "Output file opened successfully in write mode: %s\n", file_out);
-				};
-			};
+			DEBUGPRINT_WA(DEBUG_ipv6loganon_general, "Output file opened successfully in %s mode: %s", (strcmp(file_out_mode, "a") == 0) ? "append" : "write", file_out);
 			file_out_flag = 2;
 		};
 	};
@@ -270,9 +259,7 @@ int main(int argc,char *argv[]) {
 	lineparser();
 
 	if (file_out_flag == 2) {
-		if (ipv6calc_debug > 0) {
-			fprintf(stderr, "Output file is closed now: %s\n", file_out);
-		};
+		DEBUGPRINT_WA(DEBUG_ipv6loganon_general, "Output file is closed now: %s", file_out);
 		fflush(FILE_OUT);
 		fclose(FILE_OUT);
 	} else {
@@ -281,13 +268,11 @@ int main(int argc,char *argv[]) {
 
 	exit(EXIT_SUCCESS);
 };
-#undef DEBUG_function_name
 
 
 /*
  * Line parser
  */
-#define DEBUG_function_name "ipv6loganon/lineparser"
 static void lineparser(void) {
 	char linebuffer[LINEBUFFER];
 	char token[LINEBUFFER];
@@ -317,10 +302,8 @@ static void lineparser(void) {
 				fprintf(stderr, "Ok, proceeding stdin...\n");
 			};
 		};
-		
-		if (ipv6calc_debug == 1) {
-			fprintf(stderr, "Line: %d\r", linecounter);
-		};
+	
+		DEBUGPRINT_WA(DEBUG_ipv6loganon_general, "Line number: %d", linecounter);
 
 		if (strlen(linebuffer) >= LINEBUFFER) {
 			fprintf(stderr, "Line too long: %d\n", linecounter);
@@ -332,9 +315,7 @@ static void lineparser(void) {
 			continue;
 		};
 		
-		if (ipv6calc_debug != 0) {
-			fprintf(stderr, "%s: Got line: '%s'\n", DEBUG_function_name, linebuffer);
-		};
+		DEBUGPRINT_WA(DEBUG_ipv6loganon_general, "Got line: '%s'", linebuffer);
 
 		/* look for first token */
 		charptr = strtok_r(linebuffer, " \t\n", ptrptr);
@@ -349,14 +330,12 @@ static void lineparser(void) {
 			continue;
 		};
 
-		snprintf(token, sizeof(token) - 1, "%s", charptr);
+		snprintf(token, sizeof(token), "%s", charptr);
 		
-		if (ipv6calc_debug != 0) {
-			fprintf(stderr, "%s: Token 1: '%s'\n", DEBUG_function_name, token);
-		};
+		DEBUGPRINT_WA(DEBUG_ipv6loganon_general, "Token 1: '%s'", token);
 		
 		/* call anonymizer now */
-		retval = anonymizetoken(resultstring, charptr);
+		retval = anonymizetoken(resultstring, sizeof(resultstring), charptr);
 
 		if (retval != 0) {
 			continue;
@@ -398,14 +377,12 @@ static void lineparser(void) {
 	};
 	return;
 };
-#undef DEBUG_function_name
 
 
 /*
  * Anonymize token
  */
-#define DEBUG_function_name "ipv6loganon/anonymizetoken"
-static int anonymizetoken(char *resultstring, const char *token) {
+static int anonymizetoken(char *resultstring, const size_t resultstring_length, const char *token) {
 	long int inputtype = -1;
 	int retval = 1, i;
 
@@ -415,9 +392,7 @@ static int anonymizetoken(char *resultstring, const char *token) {
 	ipv6calc_macaddr   macaddr;
 	ipv6calc_eui64addr eui64addr;
 
-	if (ipv6calc_debug != 0) {
-		fprintf(stderr, "%s: Token: '%s'\n", DEBUG_function_name, token);
-	};
+	DEBUGPRINT_WA(DEBUG_ipv6loganon_general, "Token: '%s'", token);
 
        	/* clear resultstring */
 	resultstring[0] = '\0';
@@ -429,27 +404,21 @@ static int anonymizetoken(char *resultstring, const char *token) {
 	/* use cache ? */
 	if (flag_nocache == 0 && cache_lru_max > 0) {
 		/* check last seen one first */
-		if ((ipv6calc_debug & 0x4) != 0) {
-			fprintf(stderr, "LRU cache: look for key=%s\n", token);
-		};
+		DEBUGPRINT_WA(DEBUG_ipv6loganon_cache, "LRU cache: look for key=%s", token);
 
 		if (strcmp(cache_lru_key_token[cache_lru_last - 1], token) == 0) {
-			snprintf(resultstring, LINEBUFFER - 1, "%s", cache_lru_value[cache_lru_last - 1]);
+			snprintf(resultstring, resultstring_length, "%s", cache_lru_value[cache_lru_last - 1]);
 			cache_lru_statistics[0]++;
-			if ((ipv6calc_debug & 0x4) != 0) {
-				fprintf(stderr, "LRU cache: hit last line=%d key_token=%s value=%s\n", cache_lru_last - 1, token, resultstring);
-			};
+			DEBUGPRINT_WA(DEBUG_ipv6loganon_cache, "LRU cache: hit last line=%d key_token=%s value=%s", cache_lru_last - 1, token, resultstring);
 			return (0);
 		};
 		/* run backwards to first entry */
 		if (cache_lru_last > 1) {
 			for (i = cache_lru_last - 1; i > 0; i--) {
 				if (strcmp(cache_lru_key_token[i - 1], token) == 0) {
-					snprintf(resultstring, LINEBUFFER - 1, "%s", cache_lru_value[i - 1]);
+					snprintf(resultstring, resultstring_length, "%s", cache_lru_value[i - 1]);
 					cache_lru_statistics[cache_lru_last - i]++;
-					if ((ipv6calc_debug & 0x4) != 0) {
-						fprintf(stderr, "LRU cache: hit line=%d key_token=%s value=%s\n", i - 1, token, resultstring);
-					};
+					DEBUGPRINT_WA(DEBUG_ipv6loganon_cache, "LRU cache: hit line=%d key_token=%s value=%s", i - 1, token, resultstring);
 					return (0);
 				};
 			};
@@ -458,11 +427,9 @@ static int anonymizetoken(char *resultstring, const char *token) {
 		if (cache_lru_last < cache_lru_max) {
 			for (i = cache_lru_max; i > cache_lru_last; i--) {
 				if (strcmp(cache_lru_key_token[i - 1], token) == 0) {
-					snprintf(resultstring, LINEBUFFER - 1, "%s", cache_lru_value[i - 1]);
+					snprintf(resultstring, resultstring_length, "%s", cache_lru_value[i - 1]);
 					cache_lru_statistics[cache_lru_max - i + cache_lru_last]++;
-					if ((ipv6calc_debug & 0x4) != 0) {
-						fprintf(stderr, "LRU cache: hit line=%d key_token=%s value=%s\n", i - 1, token, resultstring);
-					};
+					DEBUGPRINT_WA(DEBUG_ipv6loganon_cache, "LRU cache: hit line=%d key_token=%s value=%s", i - 1, token, resultstring);
 					return (0);
 				};
 			};
@@ -477,36 +444,36 @@ static int anonymizetoken(char *resultstring, const char *token) {
 	/* autodetection */
 	inputtype = libipv6calc_autodetectinput(token);
 
-	if (ipv6calc_debug != 0) {
+	DEBUGSECTION_BEGIN(DEBUG_ipv6loganon_general)
 		if (inputtype >= 0) {
-			for (i = 0; i < (int) (sizeof(ipv6calc_formatstrings) / sizeof(ipv6calc_formatstrings[0])); i++) {
+			for (i = 0; i < MAXENTRIES_ARRAY(ipv6calc_formatstrings); i++) {
 				if (inputtype == ipv6calc_formatstrings[i].number) {
-					fprintf(stderr, "%s: Found type: %s\n", DEBUG_function_name, ipv6calc_formatstrings[i].token);
+					DEBUGPRINT_WA(DEBUG_ipv6loganon_general, "Found type: %s", ipv6calc_formatstrings[i].token);
 				};
 				break;
 			};
 		} else {
-			fprintf(stderr, "%s: Input type unknown\n", DEBUG_function_name);
+			DEBUGPRINT_NA(DEBUG_ipv6loganon_general, "Input type unknown");
 			return (1);
 		};
-	};
+	DEBUGSECTION_END
 
 	/* proceed input depending on type */	
 	switch (inputtype) {
 		case FORMAT_ipv6addr:
-			retval = addr_to_ipv6addrstruct(token, resultstring, &ipv6addr);
+			retval = addr_to_ipv6addrstruct(token, resultstring, resultstring_length, &ipv6addr);
 			break;
 
 		case FORMAT_ipv4addr:
-			retval = addr_to_ipv4addrstruct(token, resultstring, &ipv4addr);
+			retval = addr_to_ipv4addrstruct(token, resultstring, resultstring_length, &ipv4addr);
 			break;
 
 		case FORMAT_eui64:
-			retval = libeui64_addr_to_eui64addrstruct(token, resultstring, &eui64addr);
+			retval = libeui64_addr_to_eui64addrstruct(token, resultstring, resultstring_length, &eui64addr);
 			break;
 
 		case FORMAT_macaddr:
-			retval = addr_to_macaddrstruct(token, resultstring, &macaddr);
+			retval = addr_to_macaddrstruct(token, resultstring, resultstring_length, &macaddr);
 			break;
 	};
 
@@ -515,47 +482,43 @@ static int anonymizetoken(char *resultstring, const char *token) {
 		return 1;
 	};
 
-	if (ipv6calc_debug != 0) {
-		fprintf(stderr, "%s: Token: '%s'\n", DEBUG_function_name, token);
-	};
+	DEBUGPRINT_WA(DEBUG_ipv6loganon_general, "Token: '%s'", token);
 
 	/***** postprocessing input *****/
 	
-	if (ipv6calc_debug != 0) {
-		fprintf(stderr, "%s: Start of postprocessing input\n", DEBUG_function_name);
-	};
+	DEBUGPRINT_NA(DEBUG_ipv6loganon_general, "Start of postprocessing input");
 
 	if (ipv6addr.flag_valid == 1) {
 		/* anonymize IPv6 address according to settings */
 		libipv6addr_anonymize(&ipv6addr, &ipv6calc_anon_set);
 
 		/* convert IPv6 address structure to string */
-		ipv6addrstruct_to_compaddr(&ipv6addr, resultstring);
+		ipv6addrstruct_to_compaddr(&ipv6addr, resultstring, resultstring_length);
 
 	} else if (ipv4addr.flag_valid == 1) {
 		/* anonymize IPv4 address according to settings */
 		libipv4addr_anonymize(&ipv4addr, ipv6calc_anon_set.mask_ipv4, ipv6calc_anon_set.method);
 
 		/* convert IPv4 address structure to string */
-		libipv4addr_ipv4addrstruct_to_string(&ipv4addr, resultstring, 0);
+		libipv4addr_ipv4addrstruct_to_string(&ipv4addr, resultstring, resultstring_length, 0);
 
 	} else if (eui64addr.flag_valid == 1) {
 		/* anonymize EUI-64C address according to settings */
 		libeui64_anonymize(&eui64addr, &ipv6calc_anon_set);
 
 		/* convert EUI-64 address structure to string */
-		libeui64_eui64addrstruct_to_string(&eui64addr, resultstring, 0);
+		libeui64_eui64addrstruct_to_string(&eui64addr, resultstring, resultstring_length, 0);
 
 	} else if (macaddr.flag_valid == 1) {
 		/* anonymize MAC address according to settings */
 		libmacaddr_anonymize(&macaddr, &ipv6calc_anon_set);
 
 		/* convert MAC address structure to string */
-		libmacaddr_macaddrstruct_to_string(&macaddr, resultstring, 0);
+		libmacaddr_macaddrstruct_to_string(&macaddr, resultstring, resultstring_length, 0);
 
 	} else {
 		/* probably reverse DNS resolving lookup string, do not touch */
-		snprintf(resultstring, LINEBUFFER - 1, "%s", token);
+		snprintf(resultstring, resultstring_length, "%s", token);
 		return (0);
 	};
 
@@ -575,14 +538,10 @@ static int anonymizetoken(char *resultstring, const char *token) {
 		};
 
 		/* store key and value */
-		snprintf(cache_lru_key_token[cache_lru_last - 1], NI_MAXHOST - 1, "%s", token);
-		snprintf(cache_lru_value[cache_lru_last - 1], NI_MAXHOST - 1, "%s", resultstring);
-		if ((ipv6calc_debug & 0x4) != 0) {
-			fprintf(stderr, "LRU cache: fill line=%d key_token=%s value=%s\n", cache_lru_last - 1, cache_lru_key_token[cache_lru_last - 1], cache_lru_value[cache_lru_last - 1]);
-		};
+		snprintf(cache_lru_key_token[cache_lru_last - 1], NI_MAXHOST, "%s", token);
+		snprintf(cache_lru_value[cache_lru_last - 1], NI_MAXHOST, "%s", resultstring);
+		DEBUGPRINT_WA(DEBUG_ipv6loganon_cache, "LRU cache: fill line=%d key_token=%s value=%s", cache_lru_last - 1, cache_lru_key_token[cache_lru_last - 1], cache_lru_value[cache_lru_last - 1]);
 	};
 
 	return (0);
 };
-#undef DEBUG_function_name
-
